@@ -19,10 +19,29 @@ set_verbose <- function(r5r_core, verbose) {
 
 }
 
+#' Set progress argument
+#'
+#' @param r5r_core a rJava object to connect with R5 routing engine
+#' @param progress logical, passed from function above
+#'
+#' @return No return value, called for side effects.
+#' @family support functions
 
+set_progress <- function(r5r_core, progress) {
+
+  # Indicates whether or not a progress counter must be printed during long
+  # computations. Applies to detailed_itineraries(), travel_time_matrix(), and
+  # accessibility() functions
+
+  checkmate::assert_logical(progress)
+
+  r5r_core$setProgress(progress)
+}
 
 #' Set max street time
 #'
+#' Converts a time duration and speed input and converts it to distances.
+#'
 #' @param max_walk_dist numeric, Maximum walking distance (in meters) for the
 #'                      whole trip. Passed from routing functions.
 #' @param walk_speed numeric, Average walk speed in Km/h. Defaults to 3.6 Km/h.
@@ -125,8 +144,8 @@ select_mode <- function(mode, mode_egress) {
 #'
 #' @param datetime An object of POSIXct class.
 #'
-#' @return A `list` with the `date` and `time` of the trip departure as characters
-#' @return A list with 'date' and 'departure_time' names.
+#' @return A `list` with the `date` and `time` of the trip departure as
+#'   characters.
 #'
 #' @family support functions
 
@@ -134,8 +153,8 @@ posix_to_string <- function(datetime) {
 
   checkmate::assert_posixct(datetime)
 
-  tz = attr(datetime, "tzone")
-  if(is.null(tz)){tz <- ""}
+  tz <- attr(datetime, "tzone")
+  if (is.null(tz)) tz <- ""
 
   datetime_list <- list(
     date = strftime(datetime, format = "%Y-%m-%d", tz = tz),
@@ -165,16 +184,26 @@ assert_points_input <- function(df, name) {
     if (is(df, "sf")) {
 
       if (as.character(sf::st_geometry_type(df, by_geometry = FALSE)) != "POINT") {
-
-        stop(paste0("'", name, "' must be either a 'data.frame' or a 'POINT sf'."))
-
+        stop("'", name, "' must be either a 'data.frame' or a 'POINT sf'.")
       }
 
+      if (sf::st_crs(df) != sf::st_crs(4326))
+        stop(
+          "'", name, "' CRS must be WGS 84 (EPSG 4326). ",
+          "Please use either sf::set_crs() to set it or ",
+          "sf::st_transform() to reproject it."
+        )
+
       df <- sfheaders::sf_to_df(df, fill = TRUE)
       data.table::setDT(df)
       data.table::setnames(df, "x", "lon")
       data.table::setnames(df, "y", "lat")
-      checkmate::assert_names(names(df), must.include = c("id"), .var.name = name)
+      checkmate::assert_names(
+        names(df),
+        must.include = c("id"),
+        .var.name = name
+      )
+
     }
 
     checkmate::assert_names(names(df), must.include = c("id", "lat", "lon"), .var.name = name)
@@ -240,6 +269,29 @@ assert_decay_function <- function(decay_function, decay_value) {
   return(decay_list)
 }
 
+#' Assert travel times breakdown stat parameter value
+#'
+#' @param breakdown_stat Name of statistic function (minimum or average/mean).
+#'
+#' @return A character with the validated statistic function name.
+#' @family support functions
+
+assert_breakdown_stat <- function(breakdown_stat) {
+  # list of all decay functions
+  stat_functions  <- c('MIN', 'MINIMUM', 'MEAN', 'AVG', 'AVERAGE')
+
+  # check if decay_function is valid
+  checkmate::assert_character(breakdown_stat)
+  breakdown_stat <- toupper(breakdown_stat)
+
+  if (!breakdown_stat %chin% stat_functions) {
+    stop(paste0(breakdown_stat, " is not a valid 'statistic function'.\nPlease use one of the following: ",
+                paste(unique(stat_functions), collapse = ", ")))
+  }
+
+  return(breakdown_stat)
+}
+
 #' Set number of threads
 #'
 #' @description Sets number of threads to be used by the r5r .jar.
@@ -374,44 +426,43 @@ set_suboptimal_minutes <- function(r5r_core, suboptimal_minutes) {
 
 
 
-#' Download metadata of R5 jar files
-#' @description Support function to download metadata internally used in r5r
+#' Get most recent JAR filename from metadata
+#'
+#' Returns the most recent JAR filename from metadata, depending on the version.
+#'
+#' @param version A string, the version of R5's to get the filename of.
+#'
+#' @return The filename as a string.
 #'
-#' @return A `data.frame` with url address of r5r Jar files
 #' @family support functions
-#'
-download_metadata <- function(){
+filename_from_metadata <- function(version) {
 
-  # create tempfile to save metadata
-  metadata_file <- file.path(tempdir(), "metadata_r5r.csv")
+  checkmate::assert_string(version)
 
-  # IF metadata has been downloaded before
-  if (checkmate::test_file_exists(metadata_file)) {
+  metadata <- system.file("extdata/metadata_r5r.csv", package = "r5r")
+  metadata <- data.table::fread(metadata)
 
-    # skip
-
-    } else {
-
-  # Download medata
-    # test server connection
-    metadata_link <- 'https://www.ipea.gov.br/geobr/r5r/metadata.csv'
-    if (check_connection(metadata_link)) {
-      # download it and save it to JAR folder
-      utils::download.file(url=metadata_link, destfile=metadata_file,
-                           overwrite=TRUE, quiet=TRUE)
-    } else {
-      message("Using cached metadata file.")
-
-      metadata_file <- file.path(.libPaths()[1], "r5r", "extdata", "metadata_r5r.csv")
-    }
+  # check for invalid 'version' input
 
+  if (!(version %in% metadata$version)) {
+    stop(
+      "Error: Invalid value to argument 'version'. ",
+      "Please use one of the following: ",
+      paste(unique(metadata$version), collapse = "; ")
+    )
   }
 
-  # read metadata
-  metadata <- utils::read.csv(metadata_file,
-                              colClasses = 'character', header = T, sep = ';')
+  # check which jar file to download based on the 'version' parameter
+
+  env <- environment()
+  metadata <- metadata[version == get("version", envir = env)]
+  metadata <- metadata[release_date == max(release_date)]
+  url <- metadata$download_path
+
+  filename <- basename(url)
+
+  return(filename)
 
-  return(metadata)
 }
 
 
