@@ -5,7 +5,7 @@ testthat::skip_on_cran()
 
 # setup_r5
 path <- system.file("extdata/poa", package = "r5r")
-r5r_core <- setup_r5(data_path = path, verbose=FALSE)
+r5r_core <- setup_r5(data_path = path, verbose=FALSE, temp_dir = TRUE)
 
 
 # expected behavior
